"""meta data collections such as execution times."""
from .base import MetaData
from .decorators import TimeIt

__all__ = ["MetaData", "TimeIt"]
